/*
 * Copyright (c) 2022 Christian Wittenberg
 *
 * GNOME Pushover Messages shell extension is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 3 of the License, or (at your
 * option) any later version. This extension is not owned or developed by Pushover itself. 
 * Pushover, its name and logo are registered trademarks of Pushover LLC.
 *
 * GNOME Pushover Messages shell extension is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details. 
 *
 * You should have received a copy of the GNU General Public License along
 * with Gnome Documents; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * Author:
 * Christian Wittenberg <dev@iwont.cyou>
 *
 */

const {
  Adw,
  Gtk,
  Gdk,
  Gio
} = imports.gi;

const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();

// Import preferences pages
const GeneralPrefs = Me.imports.preferences.generalPage;
const AboutPrefs = Me.imports.preferences.aboutPage;

function init() {
  ExtensionUtils.initTranslations(Me.metadata['gettext-domain']);
}

function getSettings() {
  let GioSSS = Gio.SettingsSchemaSource;
  let schemaSource = GioSSS.new_from_directory(
      Me.dir.get_child("schemas").get_path(),
      GioSSS.get_default(),
      false
  );
  let schemaObj = schemaSource.lookup(
      'org.gnome.shell.extensions.pushover', true);
  if (!schemaObj) {
      throw new Error('cannot find schemas');
  }
  return new Gio.Settings({
      settings_schema: schemaObj
  });
}

function fillPreferencesWindow(window) {
  let iconTheme = Gtk.IconTheme.get_for_display(Gdk.Display.get_default());

  const settings = getSettings();
  const generalPage = new GeneralPrefs.GeneralPage(settings, window);
  const aboutPage = new AboutPrefs.AboutPage();

  let prefsWidth = 600;
  let prefsHeight = 700;

  window.set_default_size(prefsWidth, prefsHeight);
  window.set_search_enabled(true);

  window.add(generalPage);
  window.add(aboutPage);

  window.connect('close-request', () => {
      window.destroy();
  });
}